.. VisuSat documentation master file, created by
   sphinx-quickstart on Thu Nov 13 18:14:26 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

VisuSat Documentation
=====================

Welcome to the official documentation of **VisuSat**, a Python toolkit for
processing, customising, and visualising satellite data from EUMETSAT and
Copernicus Marine Service.

.. toctree::
   :maxdepth: 1
   :caption: Getting Started

   installation/installation
   installation/credentials

.. toctree::
   :maxdepth: 2
   :caption: API Reference

   src/visusat
   src/modules
   src/copernicus
   src/utils
   src/eumetsat
   src/plotting
   src/eumetsat_products_registry



.. toctree::
   :maxdepth: 1
   :caption: Examples

   examples/eumetsat_customisation
   examples/copernicus_global_model

.. toctree::
   :maxdepth: 1
   :caption: About

   license
